SystemOrganization addCategory: #ConfigurationOfCog!

Object subclass: #ConfigurationOfCog
	instanceVariableNames: 'project repositoryDir'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCog'!

!ConfigurationOfCog class methodsFor: 'private' stamp: 'jb 11/9/2010 13:56'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfCog class methodsFor: 'private' stamp: 'jb 11/9/2010 13:56'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfCog class methodsFor: 'metacello tool support' stamp: 'jb 11/9/2010 13:56'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCog class methodsFor: 'metacello tool support' stamp: 'jb 11/9/2010 13:56'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfCog class methodsFor: 'loading' stamp: 'jb 11/9/2010 13:56'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfCog class methodsFor: 'loading' stamp: 'EstebanLorenzano 7/31/2013 15:27'!
loadDevelopment
	"self loadDevelopment"

	^ (self project version: #development) load! !

!ConfigurationOfCog class methodsFor: 'loading' stamp: 'EstebanLorenzano 8/8/2013 14:09'!
loadGit 
	^ (self project version: 'git') load.! !

!ConfigurationOfCog class methodsFor: 'loading' stamp: 'EstebanLorenzano 7/31/2013 15:27'!
loadStable
	"self loadStable"

	^ (self project version: #stable) load! !

!ConfigurationOfCog class methodsFor: 'metacello tool support' stamp: 'jb 11/9/2010 13:56'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfCog class methodsFor: 'accessing' stamp: 'jb 11/9/2010 13:56'!
project

	^self new project! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'jb 11/10/2010 14:31'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
		
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Balloon-Engine-Pools'.
		
			
		spec repository: 'http://www.squeaksource.com/Alien';	
			  package: 'Alien-Core' with: [spec requires: #('Alien-Prereqs')];
			  package: 'Alien-Prereqs'.
			
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Cog' with: [ spec requires: #('VMMaker' ) ].	
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' ) ].
			
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Qwaq-VMProfiling-Plugins' with: [ spec requires: #('VMMaker' ) ].
			
		spec postLoadDoIt: #fixForPharo10.
		].! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'IgorStasenko 2/4/2011 11:06'!
baseline12: spec 
	" Alien-Prereqs are no longer used "
	<version: '1.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
		
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Balloon-Engine-Pools'.
		
		spec repository: 'http://www.squeaksource.com/Alien';	
			  package: 'Alien-Core'.

		spec repository: 'http://www.squeaksource.com/PharoSound';
			package: 'Sound'.
						
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Cog' with: [ spec requires: #('VMMaker' ) ].	
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' ) ].
			
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Qwaq-VMProfiling-Plugins' with: [ spec requires: #('VMMaker' ) ].
			
		spec postLoadDoIt: #fixForPharo10.
		].! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 3/1/2011 13:10'!
baseline13: spec 
	" Alien-Prereqs are no longer used "
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
		
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Balloon-Engine-Pools'.
		
		spec repository: 'http://www.squeaksource.com/Alien';	
			  package: 'Alien-Core'.

		spec repository: 'http://www.squeaksource.com/PharoSound';
			package: 'Sound'.
						
		spec repository: 'http://www.squeaksource.com/VMMaker';	
			  package: 'Cog' with: [ spec requires: #('VMMaker-oscog' ) ].	
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker-oscog' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' ) ].
			
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Qwaq-VMProfiling-Plugins' with: [ spec requires: #('VMMaker-oscog' ) ].
			
		spec postLoadDoIt: #fixForPharo10.
		].! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 3/30/2011 19:29'!
baseline14: spec 
	" Alien-Prereqs are no longer used "
	<version: '1.4-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
		
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Balloon-Engine-Pools'.
		
		spec repository: 'http://www.squeaksource.com/Alien';	
			  package: 'Alien-Core'.

		spec repository: 'http://www.squeaksource.com/PharoSound';
			package: 'Sound'.
						
		spec repository: 'http://www.squeaksource.com/VMMaker';	
			  package: 'Cog' with: [ spec requires: #('VMMaker-oscog' ) ].	
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker-oscog' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' ) ].
			
		spec repository: 'http://www.squeaksource.com/JBARepo';	
			  package: 'Qwaq-VMProfiling-Plugins' with: [ spec requires: #('VMMaker-oscog' ) ].
			
		spec repository: 'http://www.squeaksource.com/VMMaker';	
			  package: 'CMakeVMMaker' with: [spec requires: #('Cog') ] .
			
		spec postLoadDoIt: #fixForPharo10.
		].! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 6/29/2011 12:54'!
baseline15: spec 
	"Added OSProcess plugin"
	<version: '1.5-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/VMMaker'.
	
		spec 
			package: 'FFI-Pools' with: [	
				spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' with: [ 
				spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' with: [ 
				spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' with: [
				spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' with: [ 
				spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' with: [ 
				spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: [	
				spec repository: 'http://www.squeaksource.com/OSProcessPlugin' ];
			package: 'CMakeVMMaker' with: [
				spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #('VMConstruction-Plugins-OSProcessPlugin' 'Qwaq-VMProfiling-Plugins') ].! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'IgorStasenko 7/4/2011 23:14'!
baseline16: spec 
	"Added OSProcess plugin"
	<version: '1.6-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/VMMaker'.
	
		spec 
			package: 'FFI-Pools' 
				with: [ spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' 
				with: [ spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' 
				with: [ spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: [ spec repository: 'http://www.squeaksource.com/OSProcessPlugin' ];
			package: 'Freetype-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' 
				with: [ spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #('VMConstruction-Plugins-OSProcessPlugin' 'Qwaq-VMProfiling-Plugins' 'Freetype-Plugin') ].
		! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 7/22/2011 09:18'!
baseline17: spec 
	"Added OSProcess plugin"
	<version: '1.7-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/VMMaker'.
	
		spec 
			package: 'FFI-Pools' 
				with: [ spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' 
				with: [ spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' 
				with: [ spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: [ spec repository: 'http://www.squeaksource.com/OSProcessPlugin' ];
			package: 'Freetype-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' 
				with: [ spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'ObjectiveC-Plugin') ].
		! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 7/29/2011 18:20'!
baseline18: spec 
	"Added TestOSAPlugin plugin"
	<version: '1.8-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/VMMaker'.
	
		spec 
			package: 'FFI-Pools' 
				with: [ spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' 
				with: [ spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' 
				with: [ spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: [ spec repository: 'http://www.squeaksource.com/OSProcessPlugin' ];
			package: 'Freetype-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Applescript';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' 
				with: [ spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'ObjectiveC-Plugin'
					'Applescript-Core') ].
		! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'IgorStasenko 9/5/2011 16:05'!
baseline19: spec 
	"Added TestOSAPlugin plugin"
	<version: '1.9-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://source.squeak.org/VMMaker'.
	
		spec 
			package: 'FFI-Pools' 
				with: [ spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' 
				with: [ spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' 
				with: [ spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: [ spec repository: 'http://www.squeaksource.com/OSProcessPlugin' ];
			package: 'Freetype-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Applescript';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' 
				with: [ spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'ObjectiveC-Plugin'
					'Applescript-Core') ].
		! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 1/25/2012 09:40'!
baseline20: spec 
	"Added TestOSAPlugin plugin"
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://source.squeak.org/VMMaker'.
	
		spec 
			package: 'FFI-Pools' 
				with: [ spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' 
				with: [ spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' 
				with: [ spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: [ spec repository: 'http://www.squeaksource.com/OSProcessPlugin';
					requires: #('VMMaker-oscog') ];
			package: 'Freetype-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Applescript';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' 
				with: [ spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'ObjectiveC-Plugin'
					'Applescript-Core') ].
		
		spec for: #pharo do: [
			
			spec package: 'CogVMMakerPharoCompatibility' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoVM'].
			
			spec package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core' 'CogVMMakerPharoCompatibility') ].
			
		]! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 11/16/2012 21:16'!
baseline21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Added AioPlugin'.
		spec repository: 'http://source.squeak.org/VMMaker'.
	
		spec 
			package: 'FFI-Pools' 
				with: [ spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' 
				with: [ spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' 
				with: [ spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' 
				with: [ spec repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-AioPlugin' 
				with: [ spec repository: 'http://www.squeaksource.com/AioPlugin';
					requires: #('VMMaker-oscog') ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: [ 
					spec 
						repository: 'http://www.squeaksource.com/OSProcessPlugin';
						requires: #('VMMaker-oscog' 'VMConstruction-Plugins-AioPlugin') ];
			package: 'Freetype-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'SqueakSSL-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/SqueakSSL';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' 
				with: [ spec repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' 
				with: [ spec repository: 'http://www.squeaksource.com/Applescript';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' 
				with: [ spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-AioPlugin' 
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'SqueakSSL-Plugin'
					'ObjectiveC-Plugin'
					'Applescript-Core') ].
		
		spec for: #pharo do: [	
				
			spec package: 'CogVMMakerPharoCompatibility' 
				with: [ spec repository: 'http://www.squeaksource.com/PharoVM'].
			
			spec package: 'VMMaker-oscog' 
				with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core' 'CogVMMakerPharoCompatibility').].

		]! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 11/27/2012 17:08'!
baseline22: spec 
	<version: '2.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.

		spec repositories: [
			spec 
				repository: 'http://source.squeak.org/VMMaker';
				repository: 'http://www.squeaksource.com/PharoVM' ].
	
		spec 
			package: 'FFI-Pools' with: [ 
				spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' with: [ 
				spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' with: [ 
				spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' with: [ 
				spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' with: [ 
				spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' with: [ 
				spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' with: [ 
				spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-AioPlugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/AioPlugin';
					requires: #('VMMaker-oscog') ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/OSProcessPlugin';
					requires: #('VMMaker-oscog' 'VMConstruction-Plugins-AioPlugin') ];
			package: 'Freetype-Plugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'SqueakSSL-Plugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/SqueakSSL';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/Applescript';
					requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' with: [ 
				spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-AioPlugin' 
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'SqueakSSL-Plugin'
					'ObjectiveC-Plugin'
					'Applescript-Core') ].
		
		spec for: #pharo do: [		
			spec package: 'CogVMMakerPharoCompatibility'.
			
			spec package: 'VMMaker-oscog' with: [ 
				spec requires: #(
					'SharedPool-Speech' 
					'FFI-Pools' 
					'Balloon-Engine-Pools' 
					'Sound' 
					'Alien-Core' 
					'CogVMMakerPharoCompatibility') ].
			
			spec project: 'NativeBoostPlugin' with: [			
				spec
					className: 'ConfigurationOfNativeBoost';
					loads: #('Plugin' );
					repository: 'http://www.squeaksource.com/NativeBoost' ].
			
			spec package: 'SqueakSSL-Plugin' with: [ 
				spec repository: 'http://www.squeaksource.com/SqueakSSL' ].		
		
			spec package:  'PharoVMMaker'.
			
			spec 
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'PharoPlugins' 'CMakeVMMaker' 'PharoVMMaker');
				group: 'PharoPlugins' with: #('NativeBoostPlugin' 'SqueakSSL-Plugin') ]! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 2/13/2013 17:21'!
baseline23: spec 
	<version: '2.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.

		spec repositories: [
			spec 
				repository: 'http://source.squeak.org/VMMaker';
				repository: 'http://www.squeaksource.com/PharoVM' ].
	
		spec 
			package: 'FFI-Pools' with: [ 
				spec repository: 'http://source.squeak.org/FFI' ];
			package: 'SharedPool-Speech' with: [ 
				spec repository: 'http://www.squeaksource.com/Speech' ];
			package: 'Balloon-Engine-Pools' with: [ 
				spec repository: 'http://www.squeaksource.com/JBARepo' ];
			package: 'Sound' with: [ 
				spec repository: 'http://www.squeaksource.com/PharoSound' ];
			package: 'Alien-Core' with: [ 
				spec repository: 'http://www.squeaksource.com/Alien' ];
			package: 'VMMaker-oscog' with: [ 
				spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' with: [ 
				spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/JBARepo';
					requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-AioPlugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/AioPlugin';
					requires: #('VMMaker-oscog') ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/OSProcessPlugin';
					requires: #('VMMaker-oscog' 'VMConstruction-Plugins-AioPlugin') ];
			package: 'Freetype-Plugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/FreetypePlugin';
					requires: #('VMMaker-oscog') ];
			package: 'SqueakSSL-Plugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/SqueakSSL';
					requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/ObjectiveCBridge2';
					requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' with: [ 
				spec 
					repository: 'http://www.squeaksource.com/Applescript';
					requires: #('VMMaker-oscog') ];
				
			package: 'CMakeVMMaker' with: [ 
				spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
			spec 
				group: 'default' with: 'ALL';
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
				group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
				group: 'Plugins' with: #(
					'VMConstruction-Plugins-AioPlugin' 
					'VMConstruction-Plugins-OSProcessPlugin' 
					'Qwaq-VMProfiling-Plugins' 
					'Freetype-Plugin'
					'SqueakSSL-Plugin'
					'ObjectiveC-Plugin'
					'Applescript-Core') ].
		
		spec for: #pharo do: [		
			spec package: 'CogVMMakerPharoCompatibility'.
			
			spec package: 'VMMaker-oscog' with: [ 
				spec requires: #(
					'SharedPool-Speech' 
					'FFI-Pools' 
					'Balloon-Engine-Pools' 
					'Sound' 
					'Alien-Core' 
					'CogVMMakerPharoCompatibility') ].
			
			spec project: 'NativeBoostPlugin' with: [			
				spec
					className: 'ConfigurationOfNativeBoost';
					loads: #('Plugin' );
					repository: 'http://www.smalltalkhub.com/mc/Pharo/NativeBoost/main' ].
			
			spec package: 'SqueakSSL-Plugin' with: [ 
				spec repository: 'http://www.squeaksource.com/SqueakSSL' ].		
		
			spec package:  'PharoVMMaker'.
			
			spec 
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'PharoPlugins' 'CMakeVMMaker' 'PharoVMMaker');
				group: 'PharoPlugins' with: #('NativeBoostPlugin' 'SqueakSSL-Plugin') ]! !

!ConfigurationOfCog methodsFor: 'baselines' stamp: 'EstebanLorenzano 8/8/2013 14:05'!
baselineGit: spec 
	<version: 'git'>
	
	spec for: #common do: [
		spec blessing: #baseline.

		spec repositories: [
			spec repository: self repositoryDir ].
	
		spec 
			package: 'FFI-Pools';
			package: 'SharedPool-Speech';
			package: 'Balloon-Engine-Pools';
			package: 'Sound';
			package: 'Alien-Core';
			package: 'VMMaker-oscog' with: [ 
				spec requires: #('SharedPool-Speech' 'FFI-Pools' 'Balloon-Engine-Pools' 'Sound' 'Alien-Core') ];
			package: 'Cog' with: [ 
				spec requires: #('VMMaker-oscog' ) ];
			package: 'Qwaq-VMProfiling-Plugins' with: [ 
				spec requires: #('VMMaker-oscog' ) ];
			package: 'VMConstruction-Plugins-AioPlugin' with: [ 
				spec requires: #('VMMaker-oscog') ];
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: [ 
				spec requires: #('VMMaker-oscog' 'VMConstruction-Plugins-AioPlugin') ];
			package: 'Freetype-Plugin' with: [ 
				spec requires: #('VMMaker-oscog') ];
			package: 'SqueakSSL-Plugin' with: [ 
				spec requires: #('VMMaker-oscog') ];
			package: 'ObjectiveC-Plugin' with: [ 
				spec requires: #('VMMaker-oscog') ];
			package: 'Applescript-Core' with: [ 
				spec requires: #('VMMaker-oscog') ];
			package: 'CMakeVMMaker' with: [ 
				spec requires: #('Cog') ].	
			
			spec postLoadDoIt: #fixForPharo10.
			
		spec 
			group: 'default' with: 'ALL';
			group: 'ALL' with: #('CogVMMaker' 'Plugins' 'CMakeVMMaker');
			group: 'CogVMMaker' with: #('VMMaker-oscog' 'Cog');
			group: 'Plugins' with: #(
				'VMConstruction-Plugins-AioPlugin' 
				'VMConstruction-Plugins-OSProcessPlugin' 
				'Qwaq-VMProfiling-Plugins' 
				'Freetype-Plugin'
				'SqueakSSL-Plugin'
				'ObjectiveC-Plugin'
				'Applescript-Core') ].
		
		spec for: #pharo do: [		
			spec 
				package: 'CogVMMakerPharoCompatibility';
				package: 'VMMaker-oscog' with: [ 
					spec requires: #(
						'SharedPool-Speech' 
						'FFI-Pools' 
						'Balloon-Engine-Pools' 
						'Sound' 
						'Alien-Core' 
						'CogVMMakerPharoCompatibility') ];
				package: 'NativeBoost-CogPlugin';
			 	package: 'SqueakSSL-Plugin';
				package:  'PharoVMMaker'.
			
			spec 
				group: 'ALL' with: #('CogVMMaker' 'Plugins' 'PharoPlugins' 'CMakeVMMaker' 'PharoVMMaker');
				group: 'PharoPlugins' with: #('NativeBoost-CogPlugin' 'SqueakSSL-Plugin') ]! !

!ConfigurationOfCog methodsFor: 'symbolic versions' stamp: 'EstebanLorenzano 7/31/2013 15:26'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #'common' version: '6.7'! !

!ConfigurationOfCog methodsFor: 'doits' stamp: 'IgorStasenko 2/3/2011 11:34'!
fixForPharo10
	self fixVMMakerForPharo.
	! !

!ConfigurationOfCog methodsFor: 'doits' stamp: 'IgorStasenko 7/6/2011 05:10'!
fixFreeTypePluginForPharo

"this is obsolete, and no longer required"

(Smalltalk at:#FT2Plugin) class compile: 
	'declareCVarsIn: cg
	cg addHeaderFile: ''<ft2build.h>''.
	cg addHeaderFile: ''<freetype/tttables.h>''.
	cg addHeaderFile: ''FT_FREETYPE_H''.
	cg addHeaderFile: ''FT_OUTLINE_H''.
	cg var: ''library'' declareC: ''FT_Library library''.
	cg var: ''errorCode'' type: ''int''.'! !

!ConfigurationOfCog methodsFor: 'doits' stamp: 'IgorStasenko 2/4/2011 16:29'!
fixVMMakerForPharo
"fix VMMaker to fix bug"

"yeah, we need that "
Author fullName: 'MrVMMaker'.


ByteString compile: 'findSubstring: key in: body startingAt: start matchTable: matchTable
	"Answer the index in the string body at which the substring key first occurs, at or beyond start.  The match is determined using matchTable, which can be used to effect, eg, case-insensitive matches.  If no match is found, zero will be returned.

	The algorithm below is not optimum -- it is intended to be translated to C which will go so fast that it wont matter."
	| index |
	<primitive: ''primitiveFindSubstring'' module: ''MiscPrimitivePlugin''>
	
	<var: #key declareC: ''unsigned char *key''>
	<var: #body declareC: ''unsigned char *body''>
	<var: #matchTable declareC: ''unsigned char *matchTable''>

	key size = 0 ifTrue: [^ 0].
	start to: body size - key size + 1 do:
		[:startIndex |
		index := 1.
			[(matchTable at: (body at: startIndex+index-1) asciiValue + 1)
				= (matchTable at: (key at: index) asciiValue + 1)]
				whileTrue:
				[index = key size ifTrue: [^ startIndex].
				index := index+1]].
	^ 0
'.

Author reset.


! !

!ConfigurationOfCog methodsFor: 'doits' stamp: 'IgorStasenko 2/3/2011 16:01'!
pharoUndescoreAssignment
"in recent image that authorize underscore assignment because we load some squeak code in VMMaker if the preference is not set in this way the image should be compatible with underscore assigment"
" [Scanner allowUnderscoreAsAssignment: true.] on: Exception do: [].
"! !

!ConfigurationOfCog methodsFor: 'accessing' stamp: 'jb 11/9/2010 13:56'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCog methodsFor: 'accessing' stamp: 'EstebanLorenzano 8/8/2013 14:06'!
repositoryDir 
	^ repositoryDir ifNil: [ 'filetree://../mc' ].! !

!ConfigurationOfCog methodsFor: 'accessing' stamp: 'EstebanLorenzano 8/8/2013 14:06'!
repositoryDir: aString  
	repositoryDir := aString! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'jb 11/10/2010 13:38'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-ar.1';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMMaker' with: 'VMMaker-oscog.16';
			package: 'Alien-Prereqs' with: 'Alien-Prereqs-KenTreis.5';
			package: 'Alien-Core' with: 'Alien-Core-FernandoOlivero.64';
			package: 'Cog' with: 'Cog-JB.41'.
			
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'jb 11/10/2010 13:38'!
version11: spec 
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-ar.1';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMMaker' with: 'VMMaker-Igor.Stasenko.37';
			package: 'Alien-Prereqs' with: 'Alien-Prereqs-KenTreis.5';
			package: 'Alien-Core' with: 'Alien-Core-FernandoOlivero.64';
			package: 'Cog' with: 'Cog-JB.41'.
			
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 2/4/2011 11:06'!
version12: spec 
	<version: '1.2' imports: #('1.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.2';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker' with: 'VMMaker-oscog-Igor.Stasenko.48';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-JB.41'.
			
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 3/1/2011 13:09'!
version13: spec 
	<version: '1.3' imports: #('1.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.2';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.Stasenko.49';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44'.
			
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 3/18/2011 15:52'!
version14: spec 
	<version: '1.4' imports: #('1.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog.52';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44'.
			
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 3/23/2011 17:58'!
version15: spec 
	<version: '1.5' imports: #('1.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.54';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44'.
			
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 4/11/2011 14:29'!
version16: spec 
	<version: '1.6' imports: #('1.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.56';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.74'.
	].		! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 4/12/2011 13:29'!
version17: spec 
	<version: '1.7' imports: #('1.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog.dtl.57';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.78'.
	].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 4/23/2011 16:17'!
version18: spec 
	<version: '1.8' imports: #('1.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-MarianoMartinezPeck.66';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.96'.
	].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 4/25/2011 20:01'!
version19: spec 
	<version: '1.9' imports: #('1.8') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec 
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-MarianoMartinezPeck.66';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-MarianoMartinezPeck.99'.
	].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 5/3/2011 16:05'!
version20: spec 
	<version: '2.0' imports: #('1.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-MarianoMartinezPeck.66';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.103'.
	].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 6/14/2011 15:33'!
version21: spec
	<version: '2.1' imports: #('1.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Added OSProcessPlugin'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '6/14/2011 14:59'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin-dtl.27';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.55';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.108'. ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 7/1/2011 01:49'!
version22: spec
	<version: '2.2' imports: #('1.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Merge with oscog-eem.88'.
		spec author: 'IgorStasenko'.
		spec timestamp: '6/29/2011 17:27'.
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with:
'VMConstruction-Plugins-OSProcessPlugin-dtl.27';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.92';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.112'. ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 7/5/2011 02:17'!
version23: spec
	<version: '2.3' imports: #('1.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Added freetype plugin'.
		spec author: 'IgorStasenko'.
		spec timestamp: '4/07/2011 11:15'.
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin-dtl.27';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.92';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.115'. ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 7/7/2011 17:25'!
version24: spec
	<version: '2.4' imports: #('1.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'OSProcessPlugin and FT2Plugin works on windows'.
		spec author: 'IgorStasenko'.
"		spec timestamp:  see this method timestamp " 
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.95';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.123'. ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 7/11/2011 16:56'!
version25: spec
	<version: '2.5' imports: #('1.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Added rule 41 into bitblt plugin'.
		spec author: 'IgorStasenko'.
		spec timestamp:  '7/11/2011 16:55'.
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.96';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.123'. ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/20/2011 10:25'!
version26: spec
	<version: '2.6' imports: #('2.5' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '7/20/2011 10:24'.
		
		spec package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.125' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/20/2011 14:39'!
version27: spec
	<version: '2.7' imports: #('2.6' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '7/20/2011 14:38'.
		
		spec package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.126' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/21/2011 14:15'!
version28: spec
	<version: '2.8' imports: #('1.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '7/21/2011 14:15'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.96';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.128' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/29/2011 18:38'!
version291: spec
	<version: '2.9.1' imports: #('1.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '7/29/2011 18:30'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.45';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.109';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.131' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 7/22/2011 13:13'!
version29: spec
	<version: '2.9' imports: #('1.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'IgorStasenko'.
		spec timestamp:  '7/22/2011 13:13'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.44';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.108';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.128' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 8/25/2011 13:15'!
version30: spec
	<version: '3.0' imports: #('1.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'IgorStasenko'.
		spec timestamp:  '8/25/2011 13:13'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.45';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.122';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.136' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 8/31/2011 14:31'!
version31: spec
	<version: '3.1' imports: #('1.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec author: 'IgorStasenko'.
		spec timestamp:  '8/31/2011 14:28'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.45';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.123';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.136' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 12/10/2011 21:16'!
version32: spec
	<version: '3.2' imports: #('1.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'IgorStasenko'.
		spec timestamp:  '9/5/2011 16:05'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.31';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.61';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.45';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.123';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.136' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 12/10/2011 21:16'!
version33: spec
	<version: '3.3' imports: #('3.2' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '9/12/2011 10:15'.
		
		spec
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.138' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 12/10/2011 21:16'!
version34: spec
	<version: '3.4' imports: #('3.3' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '10/17/2011 12:10'.
		
		spec
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.124';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.140' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 12/10/2011 21:16'!
version35: spec
	<version: '3.5' imports: #('3.4' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '11/11/2011 14:32'.
		
		spec
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.139';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.141' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 12/10/2011 20:50'!
version36: spec
	<version: '3.6' imports: #('3.5' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '12/03/2011 18:30'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.142' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 1/5/2012 16:25'!
version37: spec
	<version: '3.7' imports: #('3.6' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '2 January 2012 7:20:21 pm'.
		
		spec
			package: 'Cog' with: 'Cog-eem.46';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.143' ].! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 1/12/2012 21:42'!
version38: spec
	<version: '3.8' imports: #('2.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'MarianoMartinezPeck'.
		spec timestamp:  '01/12/2012 16:05'.
		
		spec
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'Sound' with: 'Sound-StephaneDucasse.62';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.139';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';		
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.143'  ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'MarianoMartinezPeck 1/25/2012 09:47'!
version39: spec
	<version: '3.9' imports: #('3.8' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'MarianoMartinezPeck'.
		spec timestamp:  '01/25/2012 16:05'.
		
		spec
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67'
	].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 2/7/2012 04:32'!
version40: spec
	<version: '4.0' imports: #('3.9' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'IgorStasenko'.
		spec timestamp:  '7 Feb 2012'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.148';
			package: 'VMMaker' with: 'VMMaker-oscog-IgorStasenko.143'
	].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 2/18/2012 10:42'!
version41: spec
	<version: '4.1' imports: #('4.0' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '18 February 2012 10:41:44 am'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.150';
			package: 'VMMaker' with: 'VMMaker-oscog-IgorStasenko.144' ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 2/20/2012 18:51'!
version42: spec
	<version: '4.2' imports: #('4.1' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '20 February 2012 6:50:49 pm'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.151';
			package: 'VMMaker' with: 'VMMaker-oscog-EstebanLorenzano.149' ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 4/5/2012 14:07'!
version43: spec
	<version: '4.3' imports: #('4.2' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '5 April 2012 2:06:47 pm'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.153';
			package: 'VMMaker' with: 'VMMaker-oscog-EstebanLorenzano.150' ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 4/13/2012 10:34'!
version44: spec
	<version: '4.4' imports: #('4.3' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '6 April 2012 3:18:03 pm'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.154';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.150' ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 4/13/2012 10:41'!
version45: spec
	<version: '4.5' imports: #('4.4' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '13 April 2012 10:35:07 am'.
		
		spec
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.155' ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLM 4/25/2012 15:24'!
version46: spec
	<version: '4.6' imports: #('4.5' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec author: 'EstebanLorenzano'.
		spec timestamp:  '25 April 2012 9:35:37 am'.
		
		spec
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.156';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.157' ].


! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 8/31/2012 14:48'!
version47: spec
	<version: '4.7' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Added AioPlugin and SqueakSSLPlugin'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '5/1/2012 13:06'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.158';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.159'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3'. ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 8/31/2012 14:49'!
version48: spec
	<version: '4.8' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'SocketPlugin with ipv6 primitives'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '5/30/2012 16:00'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.160';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.163'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 8/31/2012 14:56'!
version49: spec
	<version: '4.9' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'SocketPlugin with ipv6 primitives'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '5/30/2012 16:00'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.161';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.170'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.161'. ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 8/31/2012 14:49'!
version50: spec
	<version: '5.0' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Fixes to use sqImageFileReadEntireImage()'.
		spec author: 'IgorStasenko'.
		spec timestamp: '7/26/2012 16:00'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.162';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.170'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3'].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 9/18/2012 17:57'!
version51: spec
	<version: '5.1' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'added new build script 1-liner for shell'.
		spec author: 'IgorStasenko'.
		spec timestamp: '9/18/2012'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-IgorStasenko.162';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.178'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3'].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 9/25/2012 13:53'!
version52: spec
	<version: '5.2' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'added new build script 1-liner for shell'.
		spec author: 'IgorStasenko'.
		spec timestamp: '9/18/2012'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.164';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.180'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3'].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 10/25/2012 16:35'!
version53: spec
	<version: '5.3' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Cairo library builds on Win32'.
		spec author: 'IgorStasenko'.
		spec timestamp: '23 Oct 2012'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.164';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.184'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3'].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 11/6/2012 11:01'!
version54: spec
	<version: '5.4' imports: #('2.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'SerialPlugin to work properly on mac and unix'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '2 November 2012 2:04:21 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.166';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.186'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3'].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 11/27/2012 17:49'!
version55: spec
	<version: '5.5' imports: #('2.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Pharo branding on pharo spec'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '27 November 2012 5:48:41 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.166';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.186'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			package: 'NativeBoost' with: '1.7';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.7' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 12/19/2012 11:57'!
version56: spec
	<version: '5.6' imports: #('2.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Merged with latest from Eliot (emm.227)'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '11 December 2012 2:28:49 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-EstebanLorenzano.68';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.228';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' 
				with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' 
				with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.188'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			package: 'NativeBoost' with: '1.7';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.7' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 1/18/2013 12:29'!
version57: spec
	<version: '5.7' imports: #('2.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- merged with Eliot''s 255'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '17 January 2013 4:49:56 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.68';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.230';
			package: 'Cog' with: 'Cog-eem.46';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.189'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			package: 'NativeBoost' with: '1.7';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.7' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 1/29/2013 16:15'!
version58: spec
	<version: '5.8' imports: #('2.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'introducing PharoVMBuilder class'.
		spec author: 'IgorStasenko'.
		spec timestamp: '29 January 2013'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.229';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.189'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			package: 'NativeBoost' with: '1.7';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-IgorStasenko.8' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 2/15/2013 17:44'!
version59: spec
	<version: '5.9' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'IgorStasenko'.
		spec timestamp: '13 February 2013'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.232';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.192' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-IgorStasenko.8' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 2/21/2013 12:06'!
version60: spec
	<version: '6.0' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'fix become crash when cogging'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '21 February 2013'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.233';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.192' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-IgorStasenko.8' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 3/20/2013 16:33'!
version611: spec
	<version: '6.1.1' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'iOS builder'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '20 March 2013'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.236';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.199' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 3/13/2013 18:11'!
version61: spec
	<version: '6.1' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'fix become crash when cogging'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '6 March 2013'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.236';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.197' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-IgorStasenko.8' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 5/30/2013 16:31'!
version621: spec
	<version: '6.2.1' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '14 May 2013 5:05:23 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.238';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.204' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 4/19/2013 14:17'!
version62: spec
	<version: '6.2' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Merged with Eliot''s 285'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '16 April 2013 5:19:23 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.237';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-dtl.63';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.200' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'IgorStasenko 5/30/2013 16:36'!
version63: spec
	<version: '6.3' imports: #('2.3-baseline' )>

	"
	-fix in freetype (Freetype-Plugin-IgorStasenko.64)
	-download thirdparty lib sources from files.pharo.org (CMakeVMMaker-IgorStasenko.205)
	"
	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'IgorStasenko'.
		spec timestamp: '30 May 2013'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.238';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.205' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.3';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'GuillermoPolito 6/17/2013 17:48'!
version64: spec
	<version: '6.4' imports: #('2.3-baseline' )>

	"
	-fix in freetype (Freetype-Plugin-IgorStasenko.64)
	-download thirdparty lib sources from files.pharo.org (CMakeVMMaker-IgorStasenko.205)
	"
	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '12 June 2013 4:01:38 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-MarianoMartinezPeck.67';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.239';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2';
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-IgorStasenko.205' ].

	spec for: #'pharo' do: [
		spec 
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.6';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/10/2013 12:57'!
version651: spec
	<version: '6.5.1' imports: #('2.3-baseline' )>

	"
	Making it work with FileSystem for latest Pharo20
	"
	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '8 July 2013 4:48:49 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-GuillermoPolito.69';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-GuillermoPolito.243';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2'.
		spec 
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.211';
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.6';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'GuillermoPolito 6/27/2013 01:30'!
version65: spec
	<version: '6.5' imports: #('2.3-baseline' )>

	"
	Making it work with FileSystem for latest Pharo20
	"
	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '12 June 2013 4:01:38 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-GuillermoPolito.69';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-GuillermoPolito.243';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2'.
		spec 
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-GuillermoPolito.209';
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.6';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/15/2013 17:39'!
version661: spec
	<version: '6.6.1' imports: #('2.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '12 July 2013 2:34:42 pm'.
		spec description: 'Added support for PharoS VM'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-GuillermoPolito.69';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.302';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2'.
		spec 
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.212';
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.6';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.16' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/10/2013 16:17'!
version66: spec
	<version: '6.6' imports: #('2.3-baseline' )>

	"
	Making it work with FileSystem for latest Pharo20
	"
	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '10 July 2013 4:17:09 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-GuillermoPolito.69';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.302';
			package: 'Cog' with: 'Cog-IgorStasenko.57';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2'.
		spec 
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.212';
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.6';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !

!ConfigurationOfCog methodsFor: 'versions' stamp: 'EstebanLorenzano 7/31/2013 15:25'!
version67: spec
	<version: '6.7' imports: #('2.3-baseline' )>

	"
	Making it work with FileSystem for latest Pharo20
	"
	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'EstebanLorenzano'.
		spec timestamp: '31 July 2013 3:24:47 pm'.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-eem.3';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'Balloon-Engine-Pools' with: 'Balloon-Engine-Pools-JB.2';
			package: 'Sound' with: 'Sound-GuillermoPolito.69';
			package: 'Alien-Core' with: 'Alien-Core-IgorStasenko.71';
			package: 'VMMaker-oscog' with: 'VMMaker-oscog-EstebanLorenzano.303';
			package: 'Cog' with: 'Cog-eem.61';
			package: 'Qwaq-VMProfiling-Plugins' with: 'Qwaq-VMProfiling-Plugins-JB.5';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-EstebanLorenzano.13';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin.oscog-eem.32';
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-IgorStasenko.64';
			package: 'ObjectiveC-Plugin' with: 'ObjectiveC-Plugin-John M McIntosh.20';
			package: 'Applescript-Core' with: 'Applescript-Core-SeanDeNigris.2'.
		spec 
			package: 'CMakeVMMaker' with: 'CMakeVMMaker-EstebanLorenzano.213';
			package: 'CogVMMakerPharoCompatibility' with: 'CogVMMakerPharoCompatibility-MarianoMartinezPeck.6';
			project: 'NativeBoostPlugin' with: '2.1';
			package: 'SqueakSSL-Plugin' with: 'SqueakSSL-Plugin-ar.3';
			package: 'PharoVMMaker' with: 'PharoVMMaker-EstebanLorenzano.9' ].
! !
